@@ -189,6 +189,33 @@ int Fl_screen_w(void) {
     return Fl::w();
 }
 
+int Fl_compose(int *del) {
+    int temp = 0;
+    auto ret = Fl::compose(temp);
+    *del = temp;
+    return ret;
+}
+
+void Fl_compose_reset(void) {
+    Fl::compose_reset();
+}
+
+int Fl_compose_state(void) {
+    return Fl::compose_state;
+}
+
+void Fl_reset_marked_text(void) {
+    Fl::reset_marked_text();
+}
+
+void Fl_insertion_point_location(int x, int y, int height) {
+    Fl::insertion_point_location(x, y, height);
+}
+
+void Fl_copy(const char* stuff, int len, int destination) {
+    Fl::copy(stuff, len, destination);
+}
+
 void Fl_paste_text(Fl_Widget *widget, int src) {
     Fl::paste(*widget, src, Fl::clipboard_plain_text);
 }
@@ -282,6 +309,11 @@ void Fl_set_font_size(int sz) {
     LOCK(FL_NORMAL_SIZE = sz)
 }
 
+int Fl_font_size(void) {
+    LOCK(int ret = FL_NORMAL_SIZE);
+    return ret;
+}
+
 void Fl_add_handler(int (*ev_handler)(int ev)) {
     Fl::add_handler(ev_handler);
 }
@@ -643,6 +675,14 @@ void Fl_remove_system_handler(int (*cb)(void *, void *)) {
     Fl::remove_system_handler(cb);
 }
 
+void Fl_add_clipboard_notify(void (*cb)(int source, void *data), void *data) {
+    Fl::add_clipboard_notify(cb, data);
+}
+
+void Fl_remove_clipboard_notify(void (*cb)(int source, void *data)) {
+    Fl::remove_clipboard_notify(cb);
+}
+
 #ifdef CFLTK_USE_GL
 int Fl_gl_visual(int mode) {
     return Fl::gl_visual(mode);
